"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
var _exportNames = {
  cleanup: true,
  render: true
};
exports.cleanup = cleanup;
exports.render = render;

var _regenerator = _interopRequireDefault(require("@babel/runtime/regenerator"));

var _asyncToGenerator2 = _interopRequireDefault(require("@babel/runtime/helpers/asyncToGenerator"));

var _objectSpread2 = _interopRequireDefault(require("@babel/runtime/helpers/objectSpread"));

var _objectWithoutProperties2 = _interopRequireDefault(require("@babel/runtime/helpers/objectWithoutProperties"));

var _testUtils = require("@vue/test-utils");

var _dom = require("@testing-library/dom");

Object.keys(_dom).forEach(function (key) {
  if (key === "default" || key === "__esModule") return;
  if (Object.prototype.hasOwnProperty.call(_exportNames, key)) return;
  Object.defineProperty(exports, key, {
    enumerable: true,
    get: function get() {
      return _dom[key];
    }
  });
});
var mountedWrappers = new Set();

function render(TestComponent) {
  var _ref = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

  var configurationCb = arguments.length > 2 ? arguments[2] : undefined;
  var _ref$store = _ref.store,
      store = _ref$store === void 0 ? null : _ref$store,
      _ref$routes = _ref.routes,
      routes = _ref$routes === void 0 ? null : _ref$routes,
      mountOptions = (0, _objectWithoutProperties2.default)(_ref, ["store", "routes"]);
  var localVue = (0, _testUtils.createLocalVue)();
  var vuexStore = null;
  var router = null;

  if (store) {
    var Vuex = require('vuex');

    localVue.use(Vuex);
    vuexStore = new Vuex.Store(store);
  }

  if (routes) {
    var VueRouter = require('vue-router');

    localVue.use(VueRouter);
    router = new VueRouter({
      routes: routes
    });
  }

  if (configurationCb && typeof configurationCb === 'function') {
    configurationCb(localVue, vuexStore, router);
  }

  if (!mountOptions.propsData && !!mountOptions.props) {
    mountOptions.propsData = mountOptions.props;
    delete mountOptions.props;
  }

  var wrapper = (0, _testUtils.mount)(TestComponent, (0, _objectSpread2.default)({
    localVue: localVue,
    router: router,
    store: vuexStore,
    attachToDocument: true,
    sync: false
  }, mountOptions));
  mountedWrappers.add(wrapper);

  if (wrapper.element.parentNode === document.body) {
    var div = document.createElement('div');
    wrapper.element.parentNode.insertBefore(div, wrapper.element);
    div.appendChild(wrapper.element);
  }

  return (0, _objectSpread2.default)({
    container: wrapper.element.parentNode,
    baseElement: document.body,
    debug: function debug() {
      return console.log((0, _dom.prettyDOM)(wrapper.element));
    },
    unmount: function unmount() {
      return wrapper.destroy();
    },
    isUnmounted: function isUnmounted() {
      return wrapper.vm._isDestroyed;
    },
    html: function html() {
      return wrapper.html();
    },
    emitted: function emitted() {
      return wrapper.emitted();
    },
    updateProps: function updateProps(_) {
      wrapper.setProps(_);
      return (0, _dom.wait)();
    },
    updateState: function updateState(_) {
      return wrapper.setData(_);
    }
  }, (0, _dom.getQueriesForElement)(wrapper.element.parentNode));
}

function cleanup() {
  mountedWrappers.forEach(cleanupAtWrapper);
}

function cleanupAtWrapper(wrapper) {
  if (wrapper.element.parentNode && wrapper.element.parentNode.parentNode === document.body) {
    document.body.removeChild(wrapper.element.parentNode);
  }

  wrapper.destroy();
  mountedWrappers.delete(wrapper);
}

Object.keys(_dom.fireEvent).forEach(function (fn) {
  _dom.fireEvent["_".concat(fn)] = _dom.fireEvent[fn];
  _dom.fireEvent[fn] =
  /*#__PURE__*/
  (0, _asyncToGenerator2.default)(
  /*#__PURE__*/
  _regenerator.default.mark(function _callee() {
    var _args = arguments;
    return _regenerator.default.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            _dom.fireEvent["_".concat(fn)].apply(_dom.fireEvent, _args);

            _context.next = 3;
            return (0, _dom.wait)();

          case 3:
          case "end":
            return _context.stop();
        }
      }
    }, _callee);
  }));
});

_dom.fireEvent.touch =
/*#__PURE__*/
function () {
  var _ref3 = (0, _asyncToGenerator2.default)(
  /*#__PURE__*/
  _regenerator.default.mark(function _callee2(elem) {
    return _regenerator.default.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            _context2.next = 2;
            return _dom.fireEvent.focus(elem);

          case 2:
            _context2.next = 4;
            return _dom.fireEvent.blur(elem);

          case 4:
          case "end":
            return _context2.stop();
        }
      }
    }, _callee2);
  }));

  return function (_x) {
    return _ref3.apply(this, arguments);
  };
}();